import { createRouter, createWebHistory, RouteRecordRaw } from "vue-router";
import Login from "@/features/login/Login.vue";
import Layout from "@/components/Layout.vue";
import { getToken } from "@/auth/auth";
import { isNil } from "lodash-es";
import { useMainStore } from "@/store";

const routes = [
  { path: "/", redirect: "/login" },
  { path: "/login", component: Login, name: "Login" },
  {
    path: "/basic",
    children: [
      {
        path: "rootOrg",
        component: () => import("@/features/rootOrg/RootOrg.vue"),
      },
      {
        path: "rootOrg/edit/:orgId",
        component: () => import("@/features/rootOrg/RootOrgEdit.vue"),
      },
      {
        path: "subOrg",
        component: () => import("@/features/subOrg/SubOrg.vue"),
      },
      {
        path: "role",
        component: () => import("@/features/roleManagement/RoleManagement.vue"),
      },
      {
        path: "user",
        component: () => import("@/features/userManagement/UserManagement.vue"),
      },
      {
        path: "user/privilege/:userId",
        component: () => import("@/features/userManagement/UserPrivilege.vue"),
      },
      {
        path: "course",
        component: () =>
          import("@/features/courseManagement/CourseManagement.vue"),
      },
    ],
    component: Layout,
  },
  {
    path: "/project",
    children: [
      {
        path: "projectManagement",
        component: () =>
          import("@/features/projectManagement/ProjectManagement.vue"),
      },
      {
        path: "datasource/:projectId",
        component: () =>
          import("@/features/projectDataManagement/ProjectDataManagement.vue"),
      },
      {
        path: "params/:projectId",
        component: () =>
          import(
            "@/features/projectParamsManagement/ProjectParamsManagement.vue"
          ),
      },
      {
        path: "papers/:projectId",
        component: () =>
          import(
            "@/features/projectPapersManagement/ProjectPapersManagement.vue"
          ),
      },
      {
        path: ":projectId/paperAnalysis/:paperId",
        component: () => import("@/features/paperAnalysis/PaperAnalysis.vue"),
      },
      {
        path: "allAnalysis/:projectId",
        component: () => import("@/features/allAnalysis/AllAnalysis2.vue"),
      },
      {
        path: "projectCompareManagement",
        component: () =>
          import(
            "@/features/projectCompareManagement/ProjectCompareManagement.vue"
          ),
      },
      {
        path: "projectCompareDetail",
        component: () =>
          import("@/features/projectCompareDetail/ProjectCompareDetail2.vue"),
      },
    ],
    component: Layout,
  },
  {
    path: "/:pathMatch(.*)*",
    name: "NotFound",
    component: () => import("@/components/PageError404.vue"),
  },
] as RouteRecordRaw[];

// 3. Create the router instance and pass the `routes` option
// You can pass in additional options here, but let's
// keep it simple for now.
const router = createRouter({
  // 4. Provide the history implementation to use. We are using the hash history for simplicity here.
  history: createWebHistory("web"),
  routes, // short for `routes: routes`
});

export async function routeLogout(params: {
  cause?: string;
  redirectTo: string;
}) {
  const store = useMainStore();
  return router.push(
    `/login?rootOrgId=${
      store.userInfo.rootOrgId === -1 ? 1 : store.userInfo.rootOrgId
    }&redirectTo=${encodeURI(params.redirectTo)}`
  );
}

router.beforeEach((to, from, next) => {
  const token = getToken();
  if (isNil(token) && to.path.includes("/login") === false) {
    routeLogout({ cause: "missingToken", redirectTo: to.fullPath })
      .then(() => next(false))
      .catch((e) => console.log(e));
  } else {
    next();
  }
});

export default router;
